@@ -15,9 +15,9 @@ Usage::
 from typing import Any, Dict, List, TYPE_CHECKING
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_sso_oidc.type_defs import (
-    ClientCreateTokenResponseTypeDef,
-    ClientRegisterClientResponseTypeDef,
-    ClientStartDeviceAuthorizationResponseTypeDef,
+    CreateTokenResponseTypeDef,
+    RegisterClientResponseTypeDef,
+    StartDeviceAuthorizationResponseTypeDef,
 )
 
 
@@ -42,14 +42,14 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [SSOOIDC.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         """
 
     def create_token(
@@ -62,9 +62,9 @@ class SSOOIDCClient:
         refreshToken: str = None,
         scope: List[str] = None,
         redirectUri: str = None,
-    ) -> ClientCreateTokenResponseTypeDef:
+    ) -> CreateTokenResponseTypeDef:
         """
-        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Client.create_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         """
 
     def generate_presigned_url(
@@ -73,21 +73,21 @@ class SSOOIDCClient:
         Params: Dict[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
-    ) -> None:
+    ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
-    ) -> ClientRegisterClientResponseTypeDef:
+    ) -> RegisterClientResponseTypeDef:
         """
-        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Client.register_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
-    ) -> ClientStartDeviceAuthorizationResponseTypeDef:
+    ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.3/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Client.start_device_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         """
